%%
%  -- usuthesis --
% 
%  A LaTeX class for the preparation of USU thesis' and dissertations.
% 
%  Update 4/8/2011---Allan McInnes is no longer at USU and, to my knowledge, there isn't
%    anyone who is maintaining the USU LaTeX class. - Mark Schmelter
%
%

%  Maintainer: Allan McInnes <amcinnes@cc.usu.edu>
%  Version: 0.92
%  Last Modified: 2006-07-20
%
%	 (last modified) Fri Apr 08 by Mark Schmelter
%  (last_modified) Wed Feb 23 13:57:57 2005 by Scott Budge <scott@goga.ece.usu.edu>
%
% SCCS Info: @(#) usuthesis.cls 2.2@(#)
% Version: 2.2
% Version created: 14:00:06, 02/23/05 
% This copy created: 14:00:07, 02/23/05
%
%  --- Usage ---
%
%  Several options can be specified with in the documentclass statement... 
%
%    Department - makes department specific format changes
%    - ece
%    - mae
% 
%    Document type - controls titlepage layout
%    - msthesis = MS plan A thesis
%    - msreport = MS plan B report
%=== - msthesisfour = MS plan A thesis four committee members ===
%    - dissertation = PhD dissertation
%    - dissertationsix = PhD dissertation with 6 committee members (plus dean)
%
%    Proposal flag - indicates that the document is a proposal rather than
%                    a finished document (alters title page layout)
%    - proposal = MS proposal
%
%    Fontsize - defaults to 11pt 
%    - 10pt
%    - 11pt
%    - 12pt
%%
%    Options example:
%      \documentclass[ece,msthesis]{usuthesis}
%
%  --- Bug Reports ---
%
%  This class file is probably not perfect. Reports of any bugs you encounter
%  are most welcome. Please email them to me at <amcinnes@cc.usu.edu>, 
%  or stop by my office (EL-241C) and tell me what the problem is. I'll do
%  my best to get it fixed ASAP.
%
%  --- Origins ---
%
%  Based on Lili Ma's modifications to version 1.6 of the original usuthesis
%  class maintained by Dr. Scott Budge and Dr. Todd Moon. That class was in 
%  turn based on a combination of the standard LaTeX book.cls, and a thesis
%  style file originating at Colorado State University. Also makes use of a
%  variety of ideas from Mark Senn's puthesis.cls Purdue University 
%  thesis class.
%
%  --- Notes ---
%
%  Setting the line spacing for the frontmatter to singlespaced is legacy from
%  the original usuthesis.sty. At some point it would be nice to change it,
%  since so much of the frontmatter seems to actually be doublespaced. But I'm
%  afraid that transition would require a lot of tinkering with the vspace's
%  and vskip's scattered throughout the frontmatter sections. I don't really
%  want to tackle that right now.
%  
%  --- Revision History ---
%
%  Note that this file is a lot more fun to work with if you have an editor
%  that supports folding, like Jedit or Emacs. Hence all the {{{ }}} pairs. 
%
%  History:
%  2005-02-18  -  Restructured original files into one class 
%              -  Moved to layout control via setspace.sty and geometry.sty 
%  2005-02-19  -  Added support for different types of title pages
%  2005-02-20  -  Added \makeappendix, \makeappendices, and redef'ed \appendix
%              -  Added \references
%              -  Consolidated several environment definitions into \newfbmatter
%              -  Added cite.sty and url.sty as required packages, to improve
%                 citation and bibliography formatting 
%  2005-02-23  -  Minor tweaks to "notation" environment
%  2005-03-03  -  Modified margin settings to ensure 1" bottom margin 
%  2005-03-04  -  Modified handling of the proposal option
%              -  Added signature blocks to proposal coversheets 
%              -  Fixed double spacing of LoT and LoF
%  2005-08-29  -  Fixes based on feedback from Pat Patterson's dissertation
%                 1. Reduced computed page count by 1
%                 2. Removed an extra blank line between "Contents" and the ToC
%                 3. Tweaked definition of \@chapter to prevent extra blank
%                    lines from being inserted into LoT and LoF (thanks to
%                    Dr. Todd Moon for help in tracking down the root cause of 
%                    this problem
%                 4. Removed extra blank lines in chapter headings, between 
%                    "Chapter xxx" and the chapter name, and between the
%                    chapter name and the body text
%                 5. Inserted an extra blank line between "References" and the
%                    reference list
%  2005-10-25  -  Improved the handling of the page count for the abstract page.
%                 Now writes the total page count to the .aux file, instead of
%                 generating an extra blank page at the end of the document.
%                 Also separated out and clarified the decrements that are
%                 applied to the page counters to get the final page count.
%  2005-10-26  -  Cleaned up handling of title page approval block formatting.
%                 Removed the Grad Dean signature line from the approval
%                 block for the msreport option (tip of the hat to Mitch 
%                 Whiteley for pointing out that grad dean approval is 
%                 unnecessary for Plan B reports.
%  2006-01-31  -  Setting of 'mae' option now sets the department and degree.
%  2006-01-31  -  Handling of proposals fixed so that the word 'proposal'
%                 actually appears on the cover sheet (tip of the hat to 
%                 Dave Woffinden for the bug report).
%  2006-07-20  -  Adjusted LoT and LoF to provide single-spacing within entries
%                 and double-spacing between entries.
%  2006-07-20  -  Alter page count (again) so that it is precisely frontmatter 
%                 (including cover page) + mainmatter. This is apparently what 
%                 the page count is supposed to be.
%  Spring 2007    Modifications were made by Serge Ballif to the file usuthesis.cls
%                 provided by the engineering department. This new document class 
%                 (renamed usu.cls) is more compatible with the graduate school requirements,
%                 and it should work for any department or program that is supervised by the
%                 USU graduate school. All of my changes are marked by
%                 the symbols. ===
%  2007-03-08  -  Added the command \lowercap to each title to enable the
%                 automatic capitalization of chapter titles as required
%                 by the graduate school. This feature is removed via the option
%                 noheadcaps in the document class. ===
%  2007-03-14  -  Added the options single, sequential, draftbox, doublebib,
%                 nochapnum, interdepartmental. These options are explained below. ===
%	 2011-04-08  -  Added the dissertationsix option which accomodates those poor 
%                 individuals who have 6 committee members, plus the dean. 
%  2011-08-05  -  Added a public abstract section following the primary abstract section
%                 as per new requirements from the School of Graduate Studies.

%  KNOWN BUGS  -  The grad school wants subsection titles to break after half a line
%                 even though it looks atrocious. They will usually let it slide.
%              -  The spacing of figure/tables may need to be tweaked.
%              -  The appendix names (i.e. Appendix A) should be bolded in the toc
%%

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{usu}[2006/07/20 v0.92 Revised USU thesis class]

%{{{ A handy macro for debugging: \IW{ <x> } will write <x> to the console
% This idea from Mark Senn's puthesis.cls
\newcommand{\IW}[1]{\immediate\write16{#1}}
%}}}

%{{{ Options passed in through class invocation
%{{{ Option declarations
%{{{ Department name definitions
%
% Used to set formatting options.
% Defaults to ece.
% Option for mae added only to provide an example - it has no effect right now.
%
\newcommand{\@@dept}{ece}
\newcommand{\set@@dept}[1]{\renewcommand{\@@dept}{#1}}
\DeclareOption{ece}{\set@@dept{ece}}
\DeclareOption{mae}{\set@@dept{mae}}
\DeclareOption{cee}{\set@@dept{cee}}
%}}}

%{{{ Document type definitions
%
% What type of document are we producing. 
% Used to determine formatting options.
%
\newcommand{\@@type}{msthesis}
\newcommand{\set@@type}[1]{\renewcommand{\@@type}{#1}}
\DeclareOption{msthesis}{\set@@type{msthesis}}
\DeclareOption{msreport}{\set@@type{msreport}}
\DeclareOption{dissertation}{\set@@type{dissertation}}
\DeclareOption{dissertationsix}{\set@@type{dissertationsix}} %=== six person committee ===
\DeclareOption{msthesisfour}{\set@@type{msthesisfour}} %=== four person committee ===
%}}}

%{{{ Proposal flag - changes the handling of signature blocks
\newif\if@isproposal \@isproposalfalse
\DeclareOption{proposal}{\@isproposaltrue}
%}}}

%{{{ Font size control
\newcommand{\@@fontsize}{11pt}
\newcommand{\set@@fontsize}[1]{\renewcommand{\@@fontsize}{#1}}
\DeclareOption{10pt}{\set@@fontsize{10pt}}
\DeclareOption{11pt}{\set@@fontsize{11pt}}
\DeclareOption{12pt}{\set@@fontsize{12pt}}
%}}}
%}}}

%======================================
% Enables sequential figure numbering
%======================================
\newif\if@sequential \@sequentialfalse
\DeclareOption{nonsequential}{\@sequentialfalse}
\DeclareOption{sequential}{\@sequentialtrue}

%======================================
% Enables draftbox option for timestamp
%======================================
\newif\if@draftbox \@draftboxfalse
\DeclareOption{draftbox}{\@draftboxtrue}

%======================================
% Enables single space for early drafts
%======================================
\newif\if@single \@singlefalse
\DeclareOption{single}{\@singletrue}

%======================================
% Enables double space for bibliography
%======================================
\newif\if@doublebib \@doublebibfalse
\DeclareOption{doublebib}{\@doublebibtrue}

%======================================
% Enables no chapter numbers option
%======================================
\newif\if@nochapnum \@nochapnumfalse
\DeclareOption{nochapnum}{\@nochapnumtrue}

%======================================
% Enables interdepartmental option for
% abstract page
%======================================
\newif\if@interdepartmental \@interdepartmentalfalse
\DeclareOption{interdepartmental}{\@interdepartmentaltrue}

%======================================
% Capitalize all headings. As of 2007,
% this is required by the grad school.
%======================================
\newif\if@headcaps \@headcapstrue
\DeclareOption{noheadcaps}{\@headcapsfalse}

%{{{ Options that we don't want to see
\newcommand{\@@classname}{usu}

\DeclareOption{notitlepage}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{twocolumn}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{landscape}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{legalpaper}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{a4paper}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{a5paper}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{executivepaper}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
\DeclareOption{b5paper}
    {\ClassWarning{\@@classname}
    {Option '\CurrentOption' is not available for \@@classname.}}
%}}}

% Catch any undeclared options and pass them to book class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}%
                \typeout{Passing '\CurrentOption' on to LaTex2e book.cls}}

% Default options
%\ExecuteOptions{}

% Process the options
\ProcessOptions\relax
%}}}

%{{{ Load the base class 
\LoadClass[letterpaper,\@@fontsize,oneside,onecolumn,titlepage]{book}[2001/04/21]
%}}}

%{{{ Set up conditional handling (i.e. if-then's)
\RequirePackage{ifthen}
\newcommand{\ifthen}[2]{\ifthenelse{#1}{#2}{}}
%}}}

%{{{ Line-spacing control
\RequirePackage{setspace}
\newcommand{\singlespaced}{\singlespacing}
\newcommand{\doublespaced}{\doublespacing}
\newcommand{\triplespaced}{\setstretch {2.6}}
%}}}

%{{{ Department-specific formatting
\ifthen{\equal{ece}{\@@dept}}
{
  % Nothing here right now
}
\ifthen{\equal{mae}{\@@dept}}
{
  % Nothing here right now
}
\ifthen{\equal{cee}{\@@dept}}
{
  % Nothing here right now
}
%}}}

%{{{ Counters for numbers of different types of pages
\newcounter{savemainpageno}
\newcounter{savefrontpageno}
\newcounter{savetotalpageno}
%}}}

%{{{ Set up margins, and other page parameters.
% Use the geometry package for margins to make our life easier
\RequirePackage{geometry}
\geometry{%
    paper=letterpaper,
    includeheadfoot,
    truedimen,
    bindingoffset=0.5in,  % bindingoffset + left = required 1.5in margin
    left=1in,
    top=1in,
    right=1in,
    bottom=1in,
    headheight=\@@fontsize,
    headsep=\baselineskip,
    footskip=0pt}

\tabskip 0.1em plus 10em minus 0.1em

% set paragraph indent spacing
\parindent 2em

% minimize orphans and widows
\clubpenalty=9999
\widowpenalty=9999
\displaywidowpenalty=9999
\brokenpenalty=9999

% reset footnote demarcation line
\renewcommand\footnoterule{%
    \kern-1pt
    \hrule\@width1.5in
    \kern.6pt}
%}}}

%{{{ Set up title page macros and defaults.

\newif\if@reportORproposal \@reportORproposalfalse
\newif\if@msfour \@msfourfalse
% ====================================================
% Set defaults for the thesis file.
% ====================================================
\newcommand{\defaultpagestyle}{topnumber}




\def\doctype#1{\gdef\Zdocument{#1}}
\def\gradyear#1{\gdef\Zyear{#1}}
\def\gradmonth#1{\gdef\Zmonth{#1}}
\def\title#1{\gdef\Ztitle{#1}}
\def\author#1{\gdef\Zauthor{#1}}
\def\degree#1{\gdef\Zdegree{#1}}
\def\departmentname#1{\gdef\Zdepartmentname{#1}}
\def\degreein#1{\gdef\Zdegreein{#1}}
\def\majorprof#1{\gdef\Zmajorprof{#1}}
\def\deptchair#1{\gdef\Zdeptchair{#1}}

\def\firstreader#1{\gdef\Zfirstreader{#1}}
\def\secondreader#1{\gdef\Zsecondreader{#1}}
\def\thirdreader#1{\gdef\Zthirdreader{#1}}
\def\fourthreader#1{\gdef\Zfourthreader{#1}}
\def\fifthreader#1{\gdef\Zfifthreader{#1}}  
\def\lastreader#1{\gdef\Zlastreader{#1}}


\def\graddean#1{\gdef\Zgraddean{#1}}
\def\deantitleA#1{\gdef\ZdeantitleA{#1}}
\def\deantitleB#1{\gdef\ZdeantitleB{#1}}

\def\programname#1{\gdef\Zprogramname{#1}} %=== name of interdepartmental program ===
\newcommand{\lowercap}[1]{\if@headcaps \uppercase\expandafter{#1} \else #1 \fi} 

%}}}

%{{{ Set some title page values based on dept option
\ifthen{\equal{ece}{\@@dept}}{%
  \departmentname{Electrical and Computer Engineering}
  \degreein{Electrical Engineering}
}
\ifthen{\equal{mae}{\@@dept}}{%
  \departmentname{Mechanical and Aerospace Engineering}
  \degreein{Mechanical Engineering}
}
\ifthen{\equal{cee}{\@@dept}}{%
  \departmentname{Civil and Environmental Engineering}
  \degreein{Civil and Environmental Engineering}
}

%}}}

%{{{ Set some title page values based on document type and the proposal flag
\ifthen{\equal{dissertation}{\@@type}}{%
  \doctype{dissertation}
  % 5 committee members, so last reader is the 4th one
  \lastreader{\Zfourthreader}
  \if@isproposal
    \doctype{proposal}
    \@reportORproposaltrue
  \fi
}
\ifthen{\equal{dissertationsix}{\@@type}}{%
  \doctype{dissertation}
  % 6 committee members, so last reader is the 5th one
  \lastreader{\Zfifthreader}
  \if@isproposal
    \doctype{proposal}
    \@reportORproposaltrue
  \fi
}
\ifthen{\equal{msthesis}{\@@type}}{%
  \doctype{thesis}
  % Only 3 committee members, so last reader is the 2nd one
  \lastreader{\Zsecondreader}
  \if@isproposal
    \doctype{proposal}
    \@reportORproposaltrue
  \fi  
}
\ifthen{\equal{msreport}{\@@type}}{%
  \doctype{report}
  % Only 3 committee members, so last reader is the 2nd one
  \lastreader{\Zsecondreader}
  \if@isproposal
    \doctype{proposal}
  \fi  
  \@reportORproposaltrue
}
%=== 4 person committee options ===
\ifthen{\equal{msthesisfour}{\@@type}}{%
  \doctype{thesis}
  % Only 3 committee members, so last reader is the 2nd one
  \lastreader{\Zthirdreader}
  \if@isproposal
    \doctype{proposal}
    \@reportORproposaltrue
  \fi  
}
%=== end 4 person committee options ===
%}}}



%{{{ Define styles for the frontmatter and main body
\def\preliminaries{%
    % Set the page numbering style
    \eject\pagestyle{\defaultpagestyle}\pagenumbering{roman}%
    \setcounter{page}{1}\eject}

\def\body{%
    % Save the number of frontmatter pages, which is 1 less than the
    % current page number
    \setcounter{savefrontpageno}{\value{page}}% 
    \addtocounter{savefrontpageno}{-1}%
    % Reset line spacing, and page numbering style
    % Reset the page counter: mainmatter is numbered from '1'
    \eject
    \if@single                                 % ===========================
      \singlespaced                            % Conditional statement for 
      \setlength{\footskip}{20pt}
    \else                                      % single spacing drafts
      \doublespaced                            %
    \fi                                        % ===========================
    \pagestyle{\defaultpagestyle}%
    \pagenumbering{arabic}\setcounter{page}{1}\eject}
%}}}

%{{{ Change footnote and page number formatting
\long\def\@makefntext#1{\parindent=18pt $^{\@thefnmark}$#1\par}
\def\ps@topnumber{\def\@oddhead{\hfil\thepage}\let\@evenhead=\@oddhead\def\@oddfoot{}\let\@evenfoot=\@oddfoot}
%}}}

%{{{ Table of Contents
\renewcommand*{\tableofcontents}{
    % USU requires the word "Contents" to appear on the toc page
    \chapter*{\headingsize \begin{center} \lowercap{Contents}\\[5ex]\end{center}}
    \hfill Page
    \@starttoc{toc}
}
%}}}

%{{{ List of Tables
% LoT should be single-spaced within entries and double-spaced between entries
\renewcommand*{\listoftables}{\sloppy\nohyphens{
    \vskip0pt
    \chapter*{\headingsize \begin{center} \lowercap{List of Tables}  \end{center}}
    \addcontentsline{toc}{chapter}{\lowercap{List of Tables}}
    \addvspace{10pt}
    \typeout{!! List of Tables...!!}
    \noindent
    Table \hfill Page\\         % newline allows us to use a vspace...
    % vspace adjusts spacing to get a doublespace between table headings
    % and table contents 
    \vspace{-\baselineskip}
    \@starttoc{lot}     
    \newpage
}}
% Ensure double-spacing between entries
\renewcommand*\l@table{\par\addvspace{\bigskipamount}\pagebreak[2]
 \@dottedtocline{1}{1.5em}{2.3em}}
%}}}

%{{{ List of Figures
% LoF should be single-spaced within entries and double-spaced between entries 
\renewcommand*{\listoffigures}{\sloppy\nohyphens{
    \vskip0pt
    \chapter*{\headingsize \begin{center} \lowercap{List of Figures} \end{center}}
    \addcontentsline{toc}{chapter}{\lowercap{List of Figures}}
    \addvspace{10pt} 
    \typeout{!! List of Figures...!!}
    \noindent
    Figure \hfill Page\\         % newline allows us to use a vspace...
    % vspace adjusts spacing to get a doublespace between table headings
    % and table contents
    \vspace{-\baselineskip} 
    \@starttoc{lof}     
    \nolinebreak
    \newpage 
}}
% Ensure double-spacing between entries
\renewcommand*\l@figure{\par\addvspace{\bigskipamount}\pagebreak[2] 
 \@dottedtocline{1}{1.5em}{2.3em}}
%}}}

%{{{ List of Algorithms
\newcommand*{\listofalgs}{
    \vskip0pt
    \chapter*{\headingsize \begin{center} List of Algorithms \end{center}}
    \addcontentsline{toc}{chapter}{\lowercap{List of Algorithms}}
    \addvspace{10pt} 
    \typeout{!! List of Algorithms...!!}
    \noindent
    Algorithm \hfill Page\\         % newline allows us to use a vspace...
    % vspace adjusts spacing to get a doublespace between table headings
    % and table contents
    \vspace{-\baselineskip}
    \@starttoc{alg}
    \newpage 
}
% Ensure double-spacing between entries
\newcommand*\l@alg{\par\addvspace{\bigskipamount}\pagebreak[2]
 \@dottedtocline{1}{1.5em}{2.3em}}
%}}}

%{{{ Set up a floating algorithm environment
\RequirePackage{float}
\floatstyle{ruled}
\newfloat{alg}{thp}{alg}[chapter]
\floatname{alg}{Algorithm}
%}}}

%{{{ Template for many of the front and back matter environments
\newcommand*{\newfbmatter}[3]
{
    \newenvironment{#1}
    % beginning definition
    {
        \chapter*{\headingsize \begin{center} \lowercap{#2} \end{center}}
        \addcontentsline{toc}{chapter}{\lowercap{#2}}
        \vskip 00pt\par
        % set the line spacing 
        \begin{#3}
    }
    % end definition
    {
        \end{#3}
        \clearpage
    }
}
%}}}

%{{{ Define some frontmatter and backmatter environments
% Acknowledgments
\newfbmatter{acknowledgments}{Acknowledgments}{doublespace}  
% Notations
\newfbmatter{notation}{Notation}{doublespace}
% Acronyms
\newfbmatter{acronyms}{Acronyms}{singlespace}
% Vita
\newfbmatter{vita}{Vita}{doublespace}
% === Frontispiece ===
\newfbmatter{frontispiece}{Frontispiece}{doublespace}
%}}}

%{{{{ Abstract page environment
\newenvironment{abstract}
% beginning definition
{
    \newpage
    \null \vskip \chapheadspace  
    \addcontentsline{toc}{chapter}{\lowercap{Abstract}}
    \begin{center}
        {\headingsize \lowercap{Abstract}}\\
        % empty line creates required triple space 
        % between 'Abstract' and title
        \ \\
        \begin{doublespace}
            \expandafter{\Ztitle}\\
        \end{doublespace}
            \ \\  % empty line to create required triple space
            by\\
            \ \\  % empty line to create required triple space
        \begin{doublespace}
            \expandafter{\Zauthor}\if@isproposal\else ,  \Zdegree \fi \\
        \end{doublespace}
            Utah State University, {\Zyear}\\
    \end{center}
    \begin{singlespace}  % Make sure that we're single spaced
        \ \\  % empty line to create required triple space
        Major Professor: {\Zmajorprof}\\
      \if@interdepartmental                                  % =======================
        Program: {\Zprogramname} \\                          % for interdepartmental
      \else                                                  % program that doesn't fit
        Department: {\Zdepartmentname}\\                     % just one department
      \fi                                                    % =======================
    \end{singlespace}
    \begin{doublespace}\indent\indent
} 
% end definition
{
    \end{doublespace}
    % place page count at the end of the abstract
    \par \bigskip
    \hfill (\ref{totalpageno} pages)
}
%}}}

%{{{{ Public abstract page environment
\newenvironment{public abstract}
% beginning definition
{
    \newpage
    \null \vskip \chapheadspace  
    \addcontentsline{toc}{chapter}{\lowercap{Public Abstract}}
    \begin{center}
        {\headingsize \lowercap{Public Abstract}}\\
        % empty line creates required triple space 
        % between 'Abstract' and title
        \ \\
        \begin{doublespace}
            \expandafter{\Ztitle}\\
        \end{doublespace}
            \ \\  % empty line to create required triple space
            by\\
            \ \\  % empty line to create required triple space
        \begin{doublespace}
            \expandafter{\Zauthor}\if@isproposal\else ,  \Zdegree \fi \\
        \end{doublespace}
            Utah State University, {\Zyear}\\
    \end{center}
    \begin{singlespace}  % Make sure that we're single spaced
        \ \\  % empty line to create required triple space
        Major Professor: {\Zmajorprof}\\
      \if@interdepartmental                                  % =======================
        Program: {\Zprogramname} \\                          % for interdepartmental
      \else                                                  % program that doesn't fit
        Department: {\Zdepartmentname}\\                     % just one department
      \fi                                                    % =======================
    \end{singlespace}
    \begin{doublespace}\indent\indent
} 
% end definition
{
    \end{doublespace}
}
%}}}

%{{{ Dedication page
\newenvironment{dedication}
% begin
{
    \newpage
    \null\vskip 200pt
    \vskip 20pt\par
}
% end  
{
    \clearpage
}
%}}}

%{{{ Title page
\renewcommand*{\maketitle}%
{{
    \thispagestyle{empty}
    \begin{center}
    
        \null\vskip \titleskip\baselineskip\vspace{\fixtitlespace}
				\ifthen{\equal{dissertationsix}{\@@type}}{\null\vspace{-4.1\baselineskip}}
				\ifthen{\equal{dissertation}{\@@type} \OR \equal{msthesisfour}{\@@type}}{\null\vspace{-3.1\baselineskip}}
        \begin{doublespace}  % USU requires doublespace title
            \titleheadingsize\uppercase\expandafter{\Ztitle}\\
            \ \\\vspace{\fixtitlespace}
           
            by\\
            
            \ \\\vspace{\fixtitlespace}
        \end{doublespace}
        \Zauthor\\[1\baselineskip]
        A \Zdocument\ submitted in partial fulfillment \\
        of the requirements for the degree\\
        \begin{doublespace}
        
            of\\
        
            \uppercase\expandafter{\Zdegree\\}
            in\\
            \Zdegreein\\
        \end{doublespace}
    \end{center}
    \vspace{\fixtitlespace}\vspace{\fixtitlespace}\vspace{\fixtitlespace}
    \ifthen{\equal{dissertationsix}{\@@type}}{\null\vspace{-3.1\baselineskip}}
    \ifthen{\equal{dissertation}{\@@type} \OR \equal{msthesisfour}{\@@type}}{\null\vspace{-2.6\baselineskip}}
    \begin{flushleft}
    % Approval block
        \ifthenelse{\equal{dissertation}{\@@type} \OR \equal{dissertationsix}{\@@type}}{%
            % if dissertation then leave room for extra row of
            % committee members in approval block
            \vspace{1\baselineskip}
        }{%
            \vspace{2\baselineskip}
        }
        
%        \ifthenelse{\equal{dissertationsix}{\@@type}}{%
%            % if dissertation then leave room for extra row of
%            % committee members in approval block
%            \vspace{1\baselineskip}
%        }{%
%            \vspace{2\baselineskip}
%        }
        Approved:
        \ifthenelse{\equal{dissertationsix}{\@@type}}{\null\vskip 1.65\baselineskip}{ \null\vskip 2\baselineskip}
            
         % first row is common to all
        \rule{2.5in}{1pt} \hspace{0.5in}  \rule{2.5in}{1pt}\\[-3pt]
        \makebox[2.5in][l]{\Zmajorprof} \hspace{0.5in}
        \makebox[2.5in][l]{\Zfirstreader}\\
        \makebox[2.5in][l]{Major Professor} \hspace{0.5in}
        \makebox[2.5in][l]{Committee Member}
        \ifthenelse{\equal{dissertationsix}{\@@type}}{\null\vskip 1.65\baselineskip}{ \null\vskip 2\baselineskip}
       
        
        % PhD committees have 5 members, so we need extra signature
        % lines if this is a dissertation
        \ifthen{\equal{dissertation}{\@@type}}{%
            % middle row
            \rule{2.5in}{1pt} \hspace{0.5in}  \rule{2.5in}{1pt}\\[-3pt]
            \makebox[2.5in][l]{\Zsecondreader} \hspace{0.5in}
            \makebox[2.5in][l]{\Zthirdreader}\\
            \makebox[2.5in][l]{Committee Member} \hspace{0.5in}
            \makebox[2.5in][l]{Committee Member}
            \null\vskip 2\baselineskip
        }
        % PhD committees with 6 members, so we need extra signature
        % lines if this is a dissertation
        \ifthen{\equal{dissertationsix}{\@@type}}{%								  
            % middle row
            \rule{2.5in}{1pt} \hspace{0.5in}  \rule{2.5in}{1pt}\\[-3pt]
            \makebox[2.5in][l]{\Zsecondreader} \hspace{0.5in}
            \makebox[2.5in][l]{\Zthirdreader}\\
            \makebox[2.5in][l]{Committee Member} \hspace{0.5in}
            \makebox[2.5in][l]{Committee Member}
            \null\vskip 1.65\baselineskip
            % middle row
            \rule{2.5in}{1pt} \hspace{0.5in}  \rule{2.5in}{1pt}\\[-3pt]
            \makebox[2.5in][l]{\Zfourthreader} \hspace{0.5in}
            \makebox[2.5in][l]{\Zfifthreader}\\
            \makebox[2.5in][l]{Committee Member} \hspace{0.5in}
            \makebox[2.5in][l]{Committee Member}
            \null\vskip 1.65\baselineskip
        }
        \ifthen{\equal{msthesisfour}{\@@type}}{%                       === for four person committees ===
            % middle row
            \rule{2.5in}{1pt} \hspace{0.5in}  \rule{2.5in}{1pt}\\[-3pt]
            \makebox[2.5in][l]{\Zsecondreader} \hspace{0.5in}
            \makebox[2.5in][l]{\Zlastreader}\\
            \makebox[2.5in][l]{Committee Member} \hspace{0.5in}
            \makebox[2.5in][l]{Committee Member}
            \null\vskip 2\baselineskip
            \@msfourtrue
        }
        % Format of the last row of signatures depends on whether or not this
        % is a proposal/report, or a thesis/dissertation (no grad dean signature
        % for the former). === conditional \@msfour added for four person committees ===
        \if@msfour
          \if@reportORproposal
          \@reportORproposalfalse
          \else
          	 \hspace{1.7in} \rule{2.5in}{1pt} \\[-3pt]                   % ==================
             \hspace{1.7in} \makebox[2.5in][l]{\Zgraddean}\\             % changed from 1.5in
             \hspace{1.7in} \makebox[2.5in][l]{\ZdeantitleA}\\              % to 1.7in to improve
             \hspace{1.7in} \makebox[2.5in][l]{\ZdeantitleB}\\ 
          \fi                                                            % alignment with
        \fi                                                              % centered USU name
        \if@reportORproposal
             \hspace{1.7in} \rule{2.5in}{1pt} \\[-3pt]
             \hspace{1.7in} \makebox[2.5in][l]{\Zlastreader}\\					 
             \hspace{1.7in} \makebox[2.5in][l]{Committee Member}         % ================== 
        \else
          \if@msfour
          \else
          \ifthenelse{\equal{dissertationsix}{\@@type}}{
             \hspace{1.7in} \rule{2.5in}{1pt} \\[-3pt]
             \hspace{1.7in} \makebox[2.5in][l]{\Zgraddean}\\
             \hspace{1.7in} \makebox[2.5in][l]{\ZdeantitleA}\\ 
             \hspace{1.7in} \makebox[2.5in][l]{\ZdeantitleB}\\    
          }{ 
          	 \rule{2.5in}{1pt} \hspace{0.5in}  \rule{2.5in}{1pt}\\[-3pt]
             \makebox[2.5in][l]{\Zlastreader} \hspace{0.5in}
             \makebox[2.5in][l]{\Zgraddean}\\
             \makebox[2.5in][l]{Committee Member} \hspace{0.5in}
             \makebox[2.5in][l]{\ZdeantitleA}\\
             \makebox[2.5in][l]{} \hspace{0.5in}
             \makebox[2.5in][l]{\ZdeantitleB}\\          
          }
          \fi
        \fi
    \end{flushleft}
    \begin{center}
    		\ifthenelse{\equal{dissertationsix}{\@@type}}{\vspace{3mm}}{\vspace{6mm}}
        
        \vfill
        UTAH STATE UNIVERSITY\\
        Logan, Utah\\
        \begin{doublespace}
            % USU requires doublespace between address and year
            {\Zyear}\\
        \end{doublespace}
   \end{center}
   \clearpage
}}
%}}}

%{{{ Copyright page
\newcommand{\makecopyright}%
{{
   \begin{center}
      \null 
      \vfill
      Copyright \hspace{5pt} \copyright \hspace{5pt} \Zauthor \hspace{5pt} \Zyear \\
      \vskip 14pt
      All Rights Reserved \\
      \vfill
   \end{center}
   \clearpage
}}
%}}}

%{{{ Signature page - I think this is legacy and not used any more
%\def\makesignature{\newpage\null\vskip 54pt
%    \begin{center} UTAH STATE UNIVERSITY \\[2\baselineskip] \end{center}
%    \begin{flushright} {\Zmonth, \Zyear} \end{flushright}
%    \par\noindent We hereby recommend that the \Zdocument\
%    \uppercase\expandafter{\Ztitle}\ prepared under our supervision by
%    \Zauthor\ be accepted as fulfilling in part requirements for the
%    degree of \Zdegree.
%    \begin{center}
%          \vskip 1\baselineskip
%          \underline{Committee on Graduate Work} \\[1\baselineskip]
%          \rule{3.5in}{1pt}\\[-8pt]
%          \makebox[3.5in][l]{Commitee Member}
%          \rule{3.5in}{1pt}\\[-8pt]
%          \makebox[3.5in][l]{Commitee Member}
%          \rule{3.5in}{1pt}\\[-8pt]
%          \makebox[3.5in][l]{Commitee Member}
%          \rule{3.5in}{1pt}\\[-8pt]
%          \makebox[3.5in][l]{Adviser}
%          \rule{3.5in}{1pt}\\[-8pt]
%          \makebox[3.5in][l]{Department Head}
%     \end{center}
%}
%}}}

%{{{ Redefine figure captioning
\renewcommand{\fnum@figure}{{\normalfont Fig.~\thefigure}}
%}}}

% ============================================
% Change spacing on the captions  
% ============================================
\def\fps@figure{tbph}%=== allow placement "here" in text ===

% ============================================
% Allow sequential figure and tables numbering  
% ============================================
\def\cl@chapter{%
  \if@sequential%
    \@elt{section}\@elt{footnote}%
  \else%
    \@elt{equation}\@elt{figure}\@elt{footnote}\@elt{section}\@elt{table}%
  \fi}
\newcounter{totalfigurecount} 
\newcounter{tempfigurecount}
\newcounter{totaltablecount}
\newcounter{temptablecount}
\renewcommand\thefigure{%
  \addtocounter{totalfigurecount}{1}%
  \if@sequential\else\thechapter.\fi\@arabic\c@figure}
\renewcommand\thetable{%
  \addtocounter{totaltablecount}{1}%
  \if@sequential\else\thechapter.\fi\@arabic\c@table}
\renewcommand\theequation{%
  \if@sequential\else\thechapter.\fi\@arabic\c@equation}
% === end sequential figure fix ===


%{{{ Alter bibliography environment
% Redefine thebibliography such that there is a triple-space between
% the bibliography title and the list of references
\renewenvironment{thebibliography}[1]
     {\chapter*{\bibname}%
     % \vskip \baselineskip
      \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}

%}}}

%{{{ BibTeX references - first parameter is .bib, second is bibstyle
\newcommand{\@@bibname}{References}
\renewcommand\bibname{\headingsize \lowercap{\@@bibname}}
\newcommand{\references}[2]
{
    \clearpage
    \refstepcounter{chapter}
    \addcontentsline{toc}{chapter}{\lowercap{\@@bibname}}
    \if@doublebib                                              % =========================
      \begin{doublespace}                                      % Conditional added to
          \bibliography{#1}                                    % allow double spacing of
          \bibliographystyle{#2}                               % the bibliography
      \end{doublespace}                                        % =========================
    \else   
      \begin{singlespace}
          \bibliography{#1}
          \bibliographystyle{#2}
      \end{singlespace}
    \fi
}
%}}}

%{{{ Appendices 
% Set up the appendix section by creating a coversheet and resetting the 
% chapter counters

% Use this if there is only one appendix
\newcommand{\makeappendix}
{
    \clearpage
    % Create 'Appendix' page, and add to TOC
    \refstepcounter{chapter}
    \null\vfil
    \begin{center}
        {\headingsize \lowercap{Appendix}}
    \end{center}
    \addcontentsline{toc}{chapter}{\lowercap{Appendix}} 
    \vfil\clearpage
}

% Use this, and the redefined \appendix, when creating multiple appendices
\newcommand{\makeappendices}
{
    \clearpage
    % Create 'Appendices' page, and add to TOC
    \refstepcounter{chapter}
    \null\vfil
    \begin{center}
        {\headingsize \lowercap{Appendices}}
    \end{center}
    \addcontentsline{toc}{chapter}{\lowercap{Appendices}} 
    \vfil\clearpage
    
    \setcounter{chapter}{0}%
    \setcounter{section}{0}%
    \renewcommand{\@chapapp}{Appendix}%
    \renewcommand{\thechapter}{\Alph{chapter}}
}

% Define a chapter-like command for creating appendices
% Note that this command inserts individual appendices into the table of
% contents as sections under the appendices heading
\renewcommand{\appendix}[1]
{
    \clearpage
    \refstepcounter{chapter}
    \@makechapterhead{#1}
    \addcontentsline{toc}{section}{\headfont\lowercap{\@chapapp{}} \thechapter\hspace{12pt} \lowercap{#1}} 
}
%}}}

%{{{ Set up chapter headings

%{{{ Tweak base class chapter setting slightly
% This is a bit of a hack, but seems to work...
% Redefine \@chapter so that we don't get spurious blank lines
% when the chapter changes in the LoT and LoF
% 

\def\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
                       \if@mainmatter
                         \refstepcounter{chapter}%
                         \if@nochapnum                          % === conditional to remove
                         \else                                  % chapter numbering ===
                         \typeout{\@chapapp\space\thechapter.}%
                         \fi
                         \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\thechapter}\lowercap{#1}}%
                       \else
                         \addcontentsline{toc}{chapter}{\lowercap{#1}}%
                       \fi
                    \else
                      \addcontentsline{toc}{chapter}{\lowercap{#1}}%
                    \fi
                    \chaptermark{#1}%
                    \ifnum \value{page}<2                            % ========================
                          \thispagestyle{empty}                      % first page has no number 
                    \fi                                              % ========================
                    % Following 2 lines commented out to remove the
                    % extra lines that were being inserted into the
                    % LoT and LoF
                    %\addtocontents{lof}{\protect\addvspace{10\p@}}%
                    %\addtocontents{lot}{\protect\addvspace{10\p@}}%
                    \if@twocolumn
                      \@topnewpage[\@makechapterhead{#2}]%
                    \else
                      \@makechapterhead{#2}%
                      \@afterheading
                    \fi}
%}}}

\def\@chapapp{Chapter}
%{{{ Heading for \chapter command (includes chapter number)
\def\@makechapterhead#1{             
    %\vspace*{\chapheadspace}%===was {25pt}===       % Space at top of text page. Now removed so that chapter heading on same line as text.
    { 
        \parindent 0pt \leftskip=0pt plus 1filll \rightskip=\leftskip
        \if@nochapnum                          % === conditional to remove
        \else                                  % chapter numbering === 
          \headingsize 
          \lowercap{\@chapapp{} \thechapter}   
        \par
        \fi
        \headingsize \lowercap{#1}   % Title.
        \par
        \nobreak                            % TeX penalty to prevent page break.
        \vskip 0.57\baselineskip            % Space between title and text. ===was 0.27===
    } 
}
%}}}
%{{{ % Heading for \chapter* command (no chapter number)
\def\@makeschapterhead#1{               
    %\vspace*{\chapheadspace}\vspace*{-15pt}%===was {10pt}===       % Space at top of page. Now removed so that chapter heading on same line as text.
    { 
        \parindent 0pt \leftskip=0pt plus 1filll \rightskip=\leftskip
                                           % Title.
        #1\par
        \nobreak                           % TeX penalty to prevent page break.
        \vskip 0.1pt plus 0pt minus 0pt    % Space between title and text.
    }  
}
%}}}

\def\@afterheading{} % Allow indenting after headings.
%}}}

%{{{ Define section heading styles
\def\chapter{\clearpage  \global\@topnum\z@ \@afterindentfalse \secdef\@chapter\@schapter}
\def\section{\@startsection {section}{1}{\z@}
    {4.20ex}{0.04ex}{\normalsize\headfont}}  
\def\subsection{\@startsection{subsection}{2}{\z@}
    {4.20ex}{0.04ex}{\normalsize\headfont}}  
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}
    {4.20ex}{0.04ex}{\normalsize\headfont}}  
\def\paragraph{\@startsection
     {paragraph}{4}{\z@}{3.25ex plus 1ex minus .2ex}{-1em}{\normalsize}}
\def\subparagraph{\@startsection
     {subparagraph}{4}{\parindent}{3.25ex plus 1ex minus
     .2ex}{-1em}{\normalsize}}  
%}}}

%{{{ Adjust TOC layout

% This command is used in "\l@chapter".
\def\mydotfill{\cleaders\hbox{$\m@th \mkern \@dotsep mu.\mkern \@dotsep mu$}\hfill}
%%%% remove this line %%%%\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern \@dotsep mu$}
\def\l@chapter#1#2{%
    \pagebreak[3]
    \vskip .75em plus 1pt \@tempdima 1.5em 
    \begingroup
        \parindent \z@ \rightskip \@pnumwidth
        \parfillskip -\@pnumwidth
        \headfont \leavevmode #1\mydotfill \hbox to\@pnumwidth{\hss #2}
        \par
    \endgroup}

%{{{ Adjust the spacing between entries in the tables of contents
%\def\@dottedtoclinelo#1#2#3{
%\def\@dottedtoclinelo#1#2#3{\ifnum #1>\c@tocdepth \else
%  \vskip \z@ \@plus2\p@
%  {\advance\leftskip \@tempdima \hbox{}\hskip -\leftskip \vspace{-\baselineskip}
%    {#2}\nobreak\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern \@dotsep
%       mu$}\hfill \nobreak 
%        \hbox to\@pnumwidth{\hfil\reset@font\rmfamily #3} \vskip 12pt}\fi
%   \@afterindenttrue
%   \vspace*{3mm}
%}         
%\renewcommand\chapter{\@startsection{chapter}{1}{\z@}
%  {-3.25ex\@plus -1ex \@minus -.2ex}
%  {1.5ex \@plus .2ex}
%  {\normalfont
%  \ifnum\value{chapter}>1 \else \addtocontents{toc}{\protect\addvspace{10pt}}\fi}}
 
\renewcommand\section{\@startsection{section}{1}{\z@}
  {-3.25ex\@plus -1ex \@minus -.2ex}
  {1.5ex \@plus .2ex}
  {\normalfont
  \ifnum\value{section}>1 \else \addtocontents{toc}{\protect\addvspace{10pt}}\fi}}

\renewcommand\subsection{\@startsection{subsection}{1}{\z@}
  {-3.25ex\@plus -1ex \@minus -.2ex}
  {1.5ex \@plus .2ex}
  {\normalfont
  \ifnum\value{subsection}>1 \else \addtocontents{toc}{\protect\addvspace{10pt}}\fi}}

\renewcommand\subsubsection{\@startsection{subsubsection}{1}{\z@}
  {-3.25ex\@plus -1ex \@minus -.2ex}
  {1.5ex \@plus .2ex}
  {\normalfont
  \ifnum\value{subsubsection}>1 \else \addtocontents{toc}{\protect\addvspace{10pt}}\fi}}  
   
   
%}}}
%}}}

%{{{ Include some other packages
%\RequirePackage{cite} % === removed because of clash with hyperref package. Use natbib instead.
\RequirePackage{url}
%}}}

%{{{ Once we're done with everything else, count total number of pages 
\AtEndDocument{%
    % A hack to get the total number of pages for the abstract pager 
    % First ensure we've finished paginating
    \clearpage%
    % Find the number of mainmatter pages. Since clearpage
    % steps the page counter we need to subtract off 1 page to get the
    % correct mainmatter count
    \setcounter{savemainpageno}{\value{page}}%
    \addtocounter{savemainpageno}{-1}%
    % Add together the mainmatter page count and frontmatter to page count
    % to get a total page count
    \setcounter{savetotalpageno}{\value{savemainpageno}}%
    \addtocounter{savetotalpageno}{\value{savefrontpageno}}%
    % Write page count to the aux file as a label, which can then
    % be referred to on the abstract page 
    \immediate\write\@mainaux{\string\newlabel{totalpageno}{{\number\value{savetotalpageno}}{\number\value{savetotalpageno}}{}{}{}}}%
}
%}}}

%{{{ Obsolete commands 
\newcommand{\gettotalpages}{%
    % We don't use this command any more. The command definition is left
    % in for purposes of backwards compatibility with older thesis.tex files.
    \IW{}
    \IW{Warning: the command 'gettotalpages' doesn't do anything anymore!}
    \IW{         You can remove it from your thesis.tex file.}
    \IW{}
}
%}}}
%}}}
% ==========================================================
% Set up quotation, quote, and verse environments  
% ==========================================================

\newenvironment{quoting}{\begin{singlespace}\vspace{-.3cm}
\begin{quote}}{\end{quote}\end{singlespace}\vspace{-.3cm}}
% ==========================================================
% Remove chapter numbering  
% ==========================================================
\if@nochapnum
\setcounter{secnumdepth}{-1}
\fi

% ==========================================================
% Set pagestyle for the document.
% Define special draft option page style
% The footer is stamped.  
% ==========================================================
\if@draftbox
  \renewcommand{\defaultpagestyle}{thesisdraft}
\fi
 

\newcommand{\draftfoottext}{DRAFT: Do Not Distribute}
\newcommand{\timestamp}{\now\ \today}

\newcounter{currenthour} \newcounter{currentminute}
\newcommand{\now}{
  \setcounter{currenthour}{\time}\divide \c@currenthour by 60
  \setcounter{currentminute}{\time}
    \multiply \c@currenthour by 60
    \addtocounter{currentminute}{-\c@currenthour}
    \divide \c@currenthour by 60
  \ifnum \c@currenthour=0 0 \fi    % force at least one digit in hour
  \thecurrenthour:%
  \ifnum \c@currentminute<10 0\fi % force two digits in minute
  \thecurrentminute
}

\def\@draftfooter{%      
  {\rm \draftfoottext}\hfil \timestamp
    \hfil \Zauthor}

\if@twoside                                                  % If two-sided
  \def\ps@thesisdraft{
    \def\@oddfoot {\@draftfooter}                            % Footer
    \def\@evenfoot{\@draftfooter}
    \def\@evenhead{\rm \hfil\thepage}                        % Left heading.
    \def\@oddhead{\hbox{}\hfil\rm\thepage}                   % Right heading.
    \def\chaptermark##1{}
    \def\sectionmark##1{}}
\else                                                        % If one-sided
  \def\ps@thesisdraft{
    \def\@oddfoot {\@draftfooter}                            % Footer
    \def\@evenfoot{}
    \def\@oddhead{\hbox{}\hfil\rm\thepage}                   % Heading.
    \def\chaptermark##1{}}
\fi

% ==================================================
% Define some commands that the user could change.
% ==================================================
\newcommand{\headingsize}{}                                  % chapter heading font size (e.g. {\Large})
\newcommand{\titleheadingsize}{}                             % title page title font size (e.g. {\large})
\newcommand{\headfont}{\bf}                                  % font of subsection and toc headings (e.g. {\bf})
\newcommand{\titleskip}{1}                                   % number of lines skipped at top of title page
\newlength{\fixtitlespace}                                   % number of lines skipped at top of title page
\setlength{\fixtitlespace}{0cm}
\newlength{\chapheadspace}                                   % number of lines skipped at top of title page
\setlength{\chapheadspace}{25pt}

% ==================================================
% Set the default for the beginning of the document.
% ==================================================
\AtBeginDocument{
  \pagestyle{\defaultpagestyle}
  \markboth{}{} 
}


\endinput
%%
%% End of file 'usuthesis.cls'.

